@@ -34,6 +34,7 @@ enum
 {
   GSASL_TOO_SMALL_BUFFER = 4,
   GSASL_GCRYPT_ERROR = GSASL_CRYPTO_ERROR,
+  GSASL_CANNOT_GET_CTX = 32,
   GSASL_NEED_CLIENT_ANONYMOUS_CALLBACK = 11,
   GSASL_NEED_CLIENT_PASSWORD_CALLBACK = 12,
   GSASL_NEED_CLIENT_PASSCODE_CALLBACK = 13,
@@ -118,6 +119,13 @@ extern const char *gsasl_server_suggest_mechanism (Gsasl * ctx,
 						   const char *mechlist)
   __attribute__ ((deprecated));
 
+extern int gsasl_base64_encode (char const *src, size_t srclength,
+				char *target, size_t targsize)
+  __attribute__ ((deprecated));
+extern int gsasl_base64_decode (char const *src,
+				char *target, size_t targsize)
+  __attribute__ ((deprecated));
+
 /* Callback prototypes */
 typedef int (*Gsasl_client_callback_anonymous) (Gsasl_session * sctx,
 						char *out, size_t * outlen);
