@@ -36,13 +36,14 @@
  * indicate the length of @output).
  *
  * The contents of the @output buffer is unspecified if this functions
- * returns anything other than GSASL_OK or GSASL_NEEDS_MORE.  If this
- * function return GSASL_OK or GSASL_NEEDS_MORE, however, the @output
- * buffer is allocated by this function, and it is the responsibility
- * of caller to deallocate it by calling free (@output).
+ * returns anything other than %GSASL_OK or %GSASL_NEEDS_MORE.  If
+ * this function return %GSASL_OK or %GSASL_NEEDS_MORE, however, the
+ * @output buffer is allocated by this function, and it is the
+ * responsibility of caller to deallocate it by calling free
+ * (@output).
  *
- * Return value: Returns GSASL_OK if authenticated terminated
- *   successfully, GSASL_NEEDS_MORE if more data is needed, or error
+ * Return value: Returns %GSASL_OK if authenticated terminated
+ *   successfully, %GSASL_NEEDS_MORE if more data is needed, or error
  *   code.
  **/
 int
@@ -50,48 +51,17 @@ gsasl_step (Gsasl_session * sctx,
 	    const char *input, size_t input_len,
 	    char **output, size_t * output_len)
 {
-  _Gsasl_step_function step;
-  _Gsasl_step_function_a astep;
-  int res;
+  Gsasl_step_function step;
 
   if (sctx == NULL)
     return GSASL_INVALID_HANDLE;
 
   if (sctx->clientp)
-    {
-      step = sctx->mech->client.step;
-      astep = sctx->mech->client.astep;
-    }
+    step = sctx->mech->client.step;
   else
-    {
-      step = sctx->mech->server.step;
-      astep = sctx->mech->server.astep;
-    }
+    step = sctx->mech->server.step;
 
-  if (astep)
-    {
-      res = astep (sctx, sctx->mech_data,
-		   input, input_len,
-		   output, output_len);
-    }
-  else
-    {
-      /* XXX once all mechanisms uses the "astep" interface, this will
-	 go away. */
-      *output_len = 1000;
-      *output = malloc (*output_len);
-      if (*output == NULL)
-	return GSASL_MALLOC_ERROR;
-
-      res = step (sctx, sctx->mech_data,
-		  input, input_len,
-		  *output, output_len);
-
-      if (res != GSASL_OK && res != GSASL_NEEDS_MORE)
-	free (*output);
-    }
-
-  return res;
+  return step (sctx, sctx->mech_data, input, input_len, output, output_len);
 }
 
 /**
@@ -104,79 +74,46 @@ gsasl_step (Gsasl_session * sctx,
  * the input and base64 encodes the output.
  *
  * The contents of the @b64output buffer is unspecified if this
- * functions returns anything other than GSASL_OK or GSASL_NEEDS_MORE.
- * If this function return GSASL_OK or GSASL_NEEDS_MORE, however, the
- * @b64output buffer is allocated by this function, and it is the
- * responsibility of caller to deallocate it by calling free
- * (@b64output).
+ * functions returns anything other than %GSASL_OK or
+ * %GSASL_NEEDS_MORE.  If this function return %GSASL_OK or
+ * %GSASL_NEEDS_MORE, however, the @b64output buffer is allocated by
+ * this function, and it is the responsibility of caller to deallocate
+ * it by calling free (@b64output).
  *
- * Return value: Returns GSASL_OK if authenticated terminated
- *   successfully, GSASL_NEEDS_MORE if more data is needed, or error
+ * Return value: Returns %GSASL_OK if authenticated terminated
+ *   successfully, %GSASL_NEEDS_MORE if more data is needed, or error
  *   code.
  **/
 int
 gsasl_step64 (Gsasl_session * sctx, const char *b64input, char **b64output)
 {
-  size_t input_len, output_len;
-  char *input, *output;
+  size_t input_len = 0, output_len = 0;
+  char *input = NULL, *output = NULL;
   int res;
 
-  if (b64input && strlen (b64input) > 0)
+  if (b64input)
     {
-      int len;
-
-      input_len = strlen (b64input) + 1;
-      input = (char *) malloc (input_len);
-      if (input == NULL)
-	return GSASL_MALLOC_ERROR;
-
-      len = gsasl_base64_decode (b64input, input, input_len);
-      if (len == -1)
-	{
-	  free (input);
-	  return GSASL_BASE64_ERROR;
-	}
-      input_len = (size_t) len;
-    }
-  else
-    {
-      input = NULL;
-      input_len = 0;
+      res = gsasl_base64_from (b64input, strlen (b64input),
+			       &input, &input_len);
+      if (res != GSASL_OK)
+	return GSASL_BASE64_ERROR;
     }
 
   res = gsasl_step (sctx, input, input_len, &output, &output_len);
 
-  if (res == GSASL_OK || res == GSASL_NEEDS_MORE)
-    {
-      size_t allen = output_len * 4 / 3 + 4;	/* XXX ? */
-      int len;
-
-      *b64output = malloc (allen);
-      if (*b64output == NULL)
-	{
-	  if (input != NULL)
-	    free (input);
-	  if (output != NULL)
-	    free (output);
-	  return GSASL_MALLOC_ERROR;
-	}
-
-      len = gsasl_base64_encode (output, output_len, *b64output, allen);
-      if (len == -1)
-	{
-	  if (input != NULL)
-	    free (input);
-	  if (output != NULL)
-	    free (output);
-	  return GSASL_BASE64_ERROR;
-	}
-
-      if (output != NULL)
-	free (output);
-    }
-
   if (input != NULL)
     free (input);
 
+  if (res == GSASL_OK || res == GSASL_NEEDS_MORE)
+    {
+      res = gsasl_base64_to (output, output_len, b64output, NULL);
+
+      if (output != NULL)
+	free (output);
+
+      if (res != GSASL_OK)
+	return res;
+    }
+
   return res;
 }
