@@ -141,8 +141,12 @@ client_callback_authentication_id (Gsasl_session_ctx * ctx,
       uid = getuid ();
       pw = getpwuid (uid);
 
-      if (pw)
-	args_info.authentication_id_arg = strdup (pw->pw_name);
+      if (pw && pw->pw_name)
+	{
+	  printf ("Using system username `%s' as authentication identity.\n",
+		  pw->pw_name);
+	  args_info.authentication_id_arg = strdup (pw->pw_name);
+	}
       else
 	args_info.authentication_id_arg =
 	  strdup (readline ("Enter authentication ID: "));
