@@ -35,63 +35,42 @@
 /* "Ali " "\xC2\xAD" "Bab" "\xC2\xAA" */
 /* "Al\xC2\xAA""dd\xC2\xAD""in\xC2\xAE" */
 
-static int
-server_cb_retrieve (Gsasl_session_ctx * xctx,
-		    const char *authentication_id,
-		    const char *authorization_id,
-		    const char *realm, char *key, size_t * keylen)
-{
-  if (!key)
-    *keylen = strlen (PASSWORD);
-
-  if (*keylen < strlen (PASSWORD))
-    return GSASL_TOO_SMALL_BUFFER;
-
-  if (key)
-    memcpy (key, PASSWORD, *keylen);
-
-  return GSASL_OK;
-}
 
 static int
-client_cb_authentication_id (Gsasl_session_ctx * xctx,
-			     char *out, size_t * outlen)
+callback (Gsasl * ctx, Gsasl_session * sctx, Gsasl_property prop)
 {
-  if (!out)
-    *outlen = strlen (USERNAME);
+  int rc = GSASL_NO_CALLBACK;
 
-  if (*outlen < strlen (USERNAME))
-    return GSASL_TOO_SMALL_BUFFER;
+  /* Get user info from user. */
 
-  if (out)
-    memcpy (out, USERNAME, *outlen);
+  switch (prop)
+    {
+    case GSASL_PASSWORD:
+      gsasl_property_set (sctx, GSASL_PASSWORD, PASSWORD);
+      rc = GSASL_OK;
+      break;
 
-  return GSASL_OK;
-}
+    case GSASL_AUTHID:
+      gsasl_property_set (sctx, GSASL_AUTHID, USERNAME);
+      rc = GSASL_OK;
+      break;
 
-static int
-client_cb_password (Gsasl_session_ctx * xctx, char *out, size_t * outlen)
-{
-  if (!out)
-    *outlen = strlen (PASSWORD);
+    default:
+      fail ("Unknown callback property %d\n", prop);
+      break;
+    }
 
-  if (*outlen < strlen (PASSWORD))
-    return GSASL_TOO_SMALL_BUFFER;
-
-  if (out)
-    memcpy (out, PASSWORD, *outlen);
-
-  return GSASL_OK;
+  return rc;
 }
 
 void
 doit (void)
 {
-  Gsasl_ctx *ctx = NULL;
-  Gsasl_session_ctx *server = NULL, *client = NULL;
+  Gsasl *ctx = NULL;
+  Gsasl_session *server = NULL, *client = NULL;
   char *s1, *s2;
   size_t s1len, s2len;
-  size_t i, j;
+  size_t i;
   int res;
 
   res = gsasl_init (&ctx);
@@ -101,12 +80,7 @@ doit (void)
       return;
     }
 
-  gsasl_server_callback_retrieve_set (ctx, server_cb_retrieve);
-
-  gsasl_client_callback_authentication_id_set (ctx,
-					       client_cb_authentication_id);
-  gsasl_client_callback_password_set (ctx, client_cb_password);
-
+  gsasl_callback_set (ctx, callback);
 
   for (i = 0; i < 5; i++)
     {
@@ -162,10 +136,10 @@ doit (void)
       free (s1);
 
       if (debug)
-	printf("\n");
+	printf ("\n");
 
-      gsasl_client_finish (client);
-      gsasl_server_finish (server);
+      gsasl_finish (client);
+      gsasl_finish (server);
     }
 
   gsasl_done (ctx);
